pub struct ParseRequest {
pub language: Language,
pub source: String,
}Expand description
One parse request sent to a worker: the source and the language to parse it as. Serialized as one JSON line (JSON escapes newlines, so a whole file is a single line).
Fields
language: Languagesource: StringTrait Implementations
Sourceimpl Clone for ParseRequest
impl Clone for ParseRequest
Sourcefn clone(&self) -> ParseRequest
fn clone(&self) -> ParseRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParseRequest
impl Debug for ParseRequest
Sourceimpl<'de> Deserialize<'de> for ParseRequest
impl<'de> Deserialize<'de> for ParseRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more